# py_midiplus_fit
This is a simple library to interact with the MiDiPLUS FIT midi controller.
A simple usage example, in the form of a tool to test the controller, is available in `__init__.py` of this package, and can be run with `python -m py_midiplus_fit`.